@@ -123,5 +123,7 @@ namespace sql {
 	// Get a column. Creates a Variant, so is slower than using typed accessors.
 	Variant STORM_FN at(EnginePtr e, const Row &row, Nat index);
 
+	// Print a row, for convenience.
+	StrBuf &STORM_FN operator <<(StrBuf &to, const Row &row);
 
 }
