@@ -173,6 +173,15 @@ BEGIN_TEST(ValueMemberTest, BS) {
 	CHECK_EQ(runFn<Int>(S("tests.bs.testActorVal")), 10);
 } END_TEST
 
+BEGIN_TEST(ValueSliceTest, BS) {
+	CHECK_EQ(runFn<Int>(S("tests.bs.sliceInitVar")), 2);
+	CHECK_EQ(runFn<Int>(S("tests.bs.sliceInitVarTmp")), 2);
+	CHECK_EQ(runFn<Int>(S("tests.bs.sliceAssignVar")), 3);
+	CHECK_EQ(runFn<Int>(S("tests.bs.sliceAssignVarTmp")), 3);
+	CHECK_EQ(runFn<Int>(S("tests.bs.sliceFnCall")), 4);
+	CHECK_EQ(runFn<Int>(S("tests.bs.sliceFnCallTmp")), 4);
+} END_TEST
+
 
 /**
  * Autocast.
@@ -328,9 +337,23 @@ BEGIN_TEST(ScopeTest, BS) {
 	CHECK_EQ(runFn<Int>(S("tests.bs.testScopeCls")), 10);
 	CHECK_EQ(runFn<Int>(S("tests.bs.testClassMember")), 20);
 	CHECK_EQ(runFn<Int>(S("tests.bs.testClassNonmember")), 20);
+	CHECK_EQ(runFn<Int>(S("tests.bs.testClassNonmemberNoDot")), 10);
+	CHECK_EQ(runFn<Int>(S("tests.bs.testClassMemberNoDot")), 20);
+	CHECK_EQ(runFn<Int>(S("tests.bs.testClassNoThis")), 20);
+	CHECK_EQ(toS(runFn<Str *>(S("tests.bs.testClassCollision"))), L"0");
 } END_TEST
 
 
+/**
+ * Initializers.
+ */
+
+BEGIN_TEST(ClassInitTest, BS) {
+	CHECK_EQ(::toS(runFn<Str *>(S("tests.bs.classDefInit"))), L"3, Hello");
+	CHECK_EQ(::toS(runFn<Str *>(S("tests.bs.classBsInit"))), L"3, Hello");
+	CHECK_EQ(::toS(runFn<Str *>(S("tests.bs.classBsInit"), Int(8))), L"8, Hello");
+} END_TEST
+
 /**
  * Units.
  */
@@ -363,6 +386,10 @@ BEGIN_TEST(ReturnTest, BS) {
 	CHECK_EQ(runFn<Int>(S("tests.bs.returnAlways"), 22), 22);
 	CHECK_EQ(runFn<Int>(S("tests.bs.deduceType"), 21), 22);
 	CHECK_EQ(runFn<Int>(S("tests.bs.prematureReturn"), 20), 30);
+
+	// Return from inline functions.
+	CHECK_EQ(runFn<Int>(S("tests.bs.inlineReturn"), 20), 18);
+	CHECK_EQ(runFn<Int>(S("tests.bs.inlineReturn"), 1), 12);
 } END_TEST
 
 /**
@@ -644,6 +671,16 @@ BEGIN_TEST(VariantStormTest, BS) {
 	CHECK_EQ(::toS(runFn<Variant>(S("tests.bs.createStrVariant")).get<Str *>()), L"test");
 	CHECK_EQ(runFn<Variant>(S("tests.bs.createIntVariant")).get<Int>(), 15);
 
+	Variant intVariant(Int(10), gEngine());
+	Variant strVariant(new (gEngine()) Str(S("TEST")));
+
+	CHECK_EQ(runFn<Int>(S("tests.bs.castVariantInt"), intVariant), 10);
+	CHECK_EQ(runFn<Int>(S("tests.bs.castVariantInt"), strVariant), -1);
+	CHECK_EQ(runFn<Int>(S("tests.bs.castVariantInt"), Variant()), -1);
+	CHECK_EQ(*runFn<Str *>(S("tests.bs.castVariantStr"), intVariant), S(""));
+	CHECK_EQ(*runFn<Str *>(S("tests.bs.castVariantStr"), strVariant), S("TEST"));
+	CHECK_EQ(*runFn<Str *>(S("tests.bs.castVariantStr"), Variant()), S(""));
+
 	// Using it together with RawPtr:
 	CHECK(runFn<Bool>(S("tests.bs.variantRawObj")));
 	CHECK(runFn<Bool>(S("tests.bs.variantRawInt")));
